==> zio-aws-kafka_3-6.20.162.1-sources.jar: zio/aws/kafka/model/package.scala <==
package zio.aws.kafka
import zio.aws.kafka.model.primitives.MaxResults.Type
import java.time.Instant
import zio.aws.kafka.model.primitives.__string
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.kafka.model.primitives.MaxResults.Type
    type __blob = Chunk[Byte]
    type __boolean = Boolean
    type __double = Double
    type __integer = Int
    type __integerMin1Max15 = Int
    type __integerMin1Max16384 = Int
    type __long = Long
    type __string = String
    type __stringMin1Max128 = String
    type __stringMin1Max64 = String
    type __stringMin5Max32 = String
    type __timestampIso8601 = Instant
  }
  type __listOfBrokerEBSVolumeInfo =
    List[zio.aws.kafka.model.BrokerEBSVolumeInfo]
  type __listOfClientVpcConnection =
    List[zio.aws.kafka.model.ClientVpcConnection]
  type __listOfCluster = List[zio.aws.kafka.model.Cluster]
  type __listOfClusterInfo = List[zio.aws.kafka.model.ClusterInfo]
  type __listOfClusterOperationInfo =
    List[zio.aws.kafka.model.ClusterOperationInfo]
  type __listOfClusterOperationStep =
    List[zio.aws.kafka.model.ClusterOperationStep]
  type __listOfClusterOperationV2Summary =
    List[zio.aws.kafka.model.ClusterOperationV2Summary]
  type __listOfCompatibleKafkaVersion =
    List[zio.aws.kafka.model.CompatibleKafkaVersion]
  type __listOfConfiguration = List[zio.aws.kafka.model.Configuration]
  type __listOfConfigurationRevision =
    List[zio.aws.kafka.model.ConfigurationRevision]
  type __listOfKafkaVersion = List[zio.aws.kafka.model.KafkaVersion]
  type __listOfNodeInfo = List[zio.aws.kafka.model.NodeInfo]
  type __listOfUnprocessedScramSecret =
    List[zio.aws.kafka.model.UnprocessedScramSecret]
  type __listOfVpcConfig = List[zio.aws.kafka.model.VpcConfig]
  type __listOfVpcConnection = List[zio.aws.kafka.model.VpcConnection]
  type __listOf__string = List[__string]
  type __mapOf__string = Map[__string, __string]
}

==> zio-aws-kafka_3-7.21.15.1-sources.jar: zio/aws/kafka/model/package.scala <==
package zio.aws.kafka
import zio.aws.kafka.model.primitives.MaxResults.Type
import java.time.Instant
import zio.aws.kafka.model.primitives.{__stringMax256, __stringMax249, __string}
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.kafka.model.primitives.MaxResults.Type
    type __blob = Chunk[Byte]
    type __boolean = Boolean
    type __double = Double
    type __integer = Int
    type __integerMin1Max15 = Int
    type __integerMin1Max16384 = Int
    type __long = Long
    type __string = String
    type __stringMax1024 = String
    type __stringMax249 = String
    type __stringMax256 = String
    type __stringMin1Max128 = String
    type __stringMin1Max128Pattern09AZaZ09AZaZ0 = String
    type __stringMin1Max64 = String
    type __stringMin5Max32 = String
    type __timestampIso8601 = Instant
  }
  type __listOfBrokerEBSVolumeInfo =
    List[zio.aws.kafka.model.BrokerEBSVolumeInfo]
  type __listOfClientVpcConnection =
    List[zio.aws.kafka.model.ClientVpcConnection]
  type __listOfCluster = List[zio.aws.kafka.model.Cluster]
  type __listOfClusterInfo = List[zio.aws.kafka.model.ClusterInfo]
  type __listOfClusterOperationInfo =
    List[zio.aws.kafka.model.ClusterOperationInfo]
  type __listOfClusterOperationStep =
    List[zio.aws.kafka.model.ClusterOperationStep]
  type __listOfClusterOperationV2Summary =
    List[zio.aws.kafka.model.ClusterOperationV2Summary]
  type __listOfCompatibleKafkaVersion =
    List[zio.aws.kafka.model.CompatibleKafkaVersion]
  type __listOfConfiguration = List[zio.aws.kafka.model.Configuration]
  type __listOfConfigurationRevision =
    List[zio.aws.kafka.model.ConfigurationRevision]
  type __listOfKafkaCluster = List[zio.aws.kafka.model.KafkaCluster]
  type __listOfKafkaClusterDescription =
    List[zio.aws.kafka.model.KafkaClusterDescription]
  type __listOfKafkaClusterSummary =
    List[zio.aws.kafka.model.KafkaClusterSummary]
  type __listOfKafkaVersion = List[zio.aws.kafka.model.KafkaVersion]
  type __listOfNodeInfo = List[zio.aws.kafka.model.NodeInfo]
  type __listOfReplicationInfo = List[zio.aws.kafka.model.ReplicationInfo]
  type __listOfReplicationInfoDescription =
    List[zio.aws.kafka.model.ReplicationInfoDescription]
  type __listOfReplicationInfoSummary =
    List[zio.aws.kafka.model.ReplicationInfoSummary]
  type __listOfReplicatorSummary = List[zio.aws.kafka.model.ReplicatorSummary]
  type __listOfUnprocessedScramSecret =
    List[zio.aws.kafka.model.UnprocessedScramSecret]
  type __listOfVpcConfig = List[zio.aws.kafka.model.VpcConfig]
  type __listOfVpcConnection = List[zio.aws.kafka.model.VpcConnection]
  type __listOf__string = List[__string]
  type __listOf__stringMax249 = List[__stringMax249]
  type __listOf__stringMax256 = List[__stringMax256]
  type __mapOf__string = Map[__string, __string]
}
